@@ -3,6 +3,8 @@
 #'
 #' Starts evaluating an R function call in a background R process, and
 #' returns immediately.
+#' Use `p$get_result()` to collect the result or to throw an error
+#' if the background computation failed.
 #'
 #' @inheritSection r Security considerations
 #' @inheritParams r
@@ -32,7 +34,7 @@ r_bg <- function(func, args = list(), libpath = .libPaths(),
                  cmdargs = c("--slave", "--no-save", "--no-restore"),
                  system_profile = FALSE, user_profile = "project",
                  env = rcmd_safe_env(), supervise = FALSE,
-                 package = FALSE, ...) {
+                 package = FALSE, arch = "same", ...) {
 
   options <- as.list(environment())
   options$extra  <- list(...)
